/* Stuff to be entered in the start of the file */
%{
#include "lexhdr.h"
TOKEN *yylval;        /* Removed it from lexmain.c  */
TOKEN currtoken;      /* yylval points to it        */
%}

/* Start of Definitions */

whitespace " "
comment    "//".*
letter     [a-zA-Z]
digit      [0-9]
integer    (("+"|"-"){digit}+)|({digit}*)
string     \".*\"
variable   {letter}({letter}|{digit})*
unknown    .


/* Grammar rules */



%%
{whitespace}  {}
{comment}     {}
{integer}     {yylval->value = atoi(yytext);
               return T_INTEGER;}  
{string}      {yylval->lexeme = yytext;
               return T_STRING;}                                    
"if"          {return T_IF;}
"else"        {return T_ELSE;}
"while"       { return T_WHILE;}
"int"         {return T_INT;}
"void"        { return T_VOID;}
"return"      {return T_RETURN;}
"("           {return T_LBRA;}
")"           {return T_RBRA;}
","           {return T_COMMA;}
";"           {return T_SEMICOLON;}
"="           {return T_EQUAL;}
"*"           {return T_STAR;}
"/"           {return T_SLASH;}
"||"          {return T_BARBAR;}
"&&"          {return T_ANDAND;}
{variable}    {yylval->lexeme = yytext;
               yylval->next = NULL; 
               add_hash(yylval);
               return T_VARIABLE;}
{unknown}     {yylval->lexeme = yytext;
               return T_UNKNOWN;}
%%
void yyinit()
{setupHT();                   /* Hash table */
 yylval = &currtoken;         /* Assign the pointer to a  variable */
}



